summaryrefslogtreecommitdiffstats
path: root/src/LashDriver.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/LashDriver.h')
-rw-r--r--src/LashDriver.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/LashDriver.h b/src/LashDriver.h
index 742c249..9f361d7 100644
--- a/src/LashDriver.h
+++ b/src/LashDriver.h
@@ -1,11 +1,11 @@
/* This file is part of Patchage. Copyright (C) 2005 Dave Robillard.
*
* Om is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* Om is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.
*
@@ -32,6 +32,12 @@ public:
void detach();
bool is_attached() const { return lash_enabled(m_client); }
+
+ bool connect(boost::shared_ptr<PatchagePort>, boost::shared_ptr<PatchagePort>)
+ { return false; }
+
+ bool disconnect(boost::shared_ptr<PatchagePort>, boost::shared_ptr<PatchagePort>)
+ { return false; }
void refresh() {}
@@ -1,11 +1,11 @@
/* This file is part of Patchage. Copyright (C) 2005 Dave Robillard.
*
- * Om is free software; you can redistribute it and/or modify it under the
+ * Patchage is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
@@ -1,11 +1,11 @@
* version.
*
- * Om is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Patchage is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.